OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migration in progress. Please wait until the migration is finished",
    "Migration started …" : "Migration started …",
    "Saved" : "Saved",
    "Not saved" : "Not saved",
    "Sending…" : "Sending…",
    "Email sent" : "Email sent",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "An error occurred. Please upload an ASCII-encoded PEM certificate.",
    "Valid until {date}" : "Valid until {date}",
    "Delete" : "Delete",
    "Local" : "Local",
    "Private" : "Private",
    "Only visible to local users" : "Only visible to local users",
    "Only visible to you" : "Only visible to you",
    "Contacts" : "Contacts",
    "Visible to local users and to trusted servers" : "Visible to local users and to trusted servers",
    "Public" : "Public",
    "Will be synced to a global and public address book" : "Will be synced to a global and public address book",
    "Verify" : "Verify",
    "Verifying …" : "Verifying …",
    "Unable to change password" : "Unable to change password",
    "Very weak password" : "Very weak password",
    "Weak password" : "Weak password",
    "So-so password" : "So-so password",
    "Good password" : "Good password",
    "Strong password" : "Strong password",
    "Select a profile picture" : "Select a profile picture",
    "Groups" : "Groups",
    "{actor} changed your password" : "{actor} changed your password",
    "You changed your password" : "You changed your password",
    "Your password was reset by an administrator" : "Your password was reset by an administrator",
    "{actor} changed your email address" : "{actor} changed your email address",
    "You changed your email address" : "You changed your email address",
    "Your email address was changed by an administrator" : "Your email address was changed by an administrator",
    "Security" : "Security",
    "You successfully logged in using two-factor authentication (%1$s)" : "You successfully logged in using two-factor authentication (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "A login attempt using two-factor authentication failed (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Your <strong>password</strong> or <strong>email</strong> was modified",
    "Couldn't remove app." : "Couldn't remove app.",
    "Couldn't update app." : "Couldn't update app.",
    "Wrong password" : "Incorrect password",
    "No user supplied" : "No user supplied",
    "Authentication error" : "Authentication error",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Please provide an admin recovery password; otherwise, all user data will be lost.",
    "Wrong admin recovery password. Please check the password and try again." : "Incorrect admin recovery password. Please check the password and try again.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Backend doesn't support password change, but the user's encryption key was updated.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "installing and updating apps via the app store or Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Invalid SMTP password." : "Invalid SMTP password.",
    "Email setting test" : "Email setting test",
    "Well done, %s!" : "Well done, %s!",
    "If you received this email, the email configuration seems to be correct." : "If you received this email, the email configuration seems to be correct.",
    "Email could not be sent. Check your mail server log" : "Email could not be sent. Check your mail server log",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "A problem occurred while sending the email. Please revise your settings. (Error: %s)",
    "You need to set your user email before being able to send test emails." : "You need to set your user email before being able to send test emails.",
    "Invalid mail address" : "Invalid mail address",
    "Settings saved" : "Settings saved",
    "Unable to change full name" : "Unable to change full name",
    "Unable to change email address" : "Unable to change email address",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):",
    "%1$s changed your password on %2$s." : "%1$s changed your password on %2$s.",
    "Your password on %s was changed." : "Your password on %s was changed.",
    "Your password on %s was reset by an administrator." : "Your password on %s was reset by an administrator.",
    "Password for %1$s changed on %2$s" : "Password for %1$s changed on %2$s",
    "Password changed for %s" : "Password changed for %s",
    "If you did not request this, please contact an administrator." : "If you did not request this, please contact an administrator.",
    "Your email address on %s was changed." : "Your email address on %s was changed.",
    "Your email address on %s was changed by an administrator." : "Your email address on %s was changed by an administrator.",
    "Email address for %1$s changed on %2$s" : "Email address for %1$s changed on %2$s",
    "Email address changed for %s" : "Email address changed for %s",
    "The new email address is %s" : "The new email address is %s",
    "Your %s account was created" : "Your %s account was created",
    "Welcome aboard" : "Welcome aboard",
    "Welcome aboard %s" : "Welcome aboard %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Welcome to your %s account, you can add, protect, and share your data.",
    "Your username is: %s" : "Your username is: %s",
    "Set your password" : "Set your password",
    "Go to %s" : "Go to %s",
    "Install Client" : "Install Client",
    "Unlimited" : "Unlimited",
    "Limit to groups" : "Limit to groups",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Official apps are developed by the community. They offer additional functionality and are ready for production use.",
    "Official" : "Official",
    "Remove" : "Remove",
    "Disable" : "Disable",
    "All" : "All",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "This app has no minimum Nextcloud version assigned. This will cause an error in the future.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "This app has no maximum Nextcloud version assigned. This will cause an error in the future.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "This app cannot be installed because the following dependencies are not fulfilled:",
    "View in store" : "View in store",
    "Visit website" : "Visit website",
    "Report a bug" : "Report a bug",
    "User documentation" : "User documentation",
    "Admin documentation" : "Admin documentation",
    "Developer documentation" : "Developer documentation",
    "No apps found for your version" : "No apps found for your version",
    "Enable all" : "Enable all",
    "Enable" : "Enable",
    "The app will be downloaded from the app store" : "The app will be downloaded from the app store",
    "Allow filesystem access" : "Allow filesystem access",
    "Revoke" : "Revoke",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "Nextcloud Talk for iOS" : "Nextcloud Talk for iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk for Android",
    "Sync client - {os}" : "Sync client - {os}",
    "This session" : "This session",
    "Device" : "Device",
    "Last activity" : "Last activity",
    "Devices & sessions" : "Devices & sessions",
    "Web, desktop and mobile clients currently logged in to your account." : "Web, desktop and mobile clients currently logged in to your account.",
    "Error while creating device token" : "Error while creating device token",
    "Error while deleting the token" : "Error while deleting the token",
    "App name" : "App name",
    "Create new app password" : "Create new app password",
    "Use the credentials below to configure your app or device." : "Use the credentials below to configure your app or device.",
    "For security reasons this password will only be shown once." : "For security reasons this password will only be shown once.",
    "Username" : "Username",
    "Password" : "Password",
    "Done" : "Done",
    "Copied!" : "Copied!",
    "Copy" : "Copy",
    "New password" : "New password",
    "{size} used" : "{size} used",
    "Email" : "Email",
    "Group admin for" : "Group admin for",
    "Quota" : "Quota",
    "Language" : "Language",
    "Storage location" : "Storage location",
    "User backend" : "User backend",
    "Last login" : "Last login",
    "Default quota" : "Default quota",
    "Your apps" : "Your apps",
    "Disabled apps" : "Disabled apps",
    "Updates" : "Updates",
    "App bundles" : "App bundles",
    "Show last login" : "Show last login",
    "Show user backend" : "Show user backend",
    "Admins" : "Admins",
    "Everyone" : "Everyone",
    "Add group" : "Add group",
    "An error occured during the request. Unable to proceed." : "An error occured during the request. Unable to proceed.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds.",
    "App update" : "App update",
    "Error: This app can not be enabled because it makes the server unstable" : "Error: This app can not be enabled because it makes the server unstable",
    "SSL Root Certificates" : "SSL Root Certificates",
    "Common Name" : "Common Name",
    "Valid until" : "Valid until",
    "Issued By" : "Issued By",
    "Valid until %s" : "Valid until %s",
    "Import root certificate" : "Import root certificate",
    "Administrator documentation" : "Administrator documentation",
    "Forum" : "Forum",
    "None" : "None",
    "Login" : "Login",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Email server",
    "Open documentation" : "Open documentation",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "It is important to set up this server to be able to send emails, like for password reset and notifications.",
    "Send mode" : "Send mode",
    "Encryption" : "Encryption",
    "From address" : "From address",
    "mail" : "mail",
    "Authentication method" : "Authentication method",
    "Authentication required" : "Authentication required",
    "Server address" : "Server address",
    "Port" : "Port",
    "Credentials" : "Credentials",
    "SMTP Username" : "SMTP Username",
    "SMTP Password" : "SMTP Password",
    "Test email settings" : "Test email settings",
    "Send email" : "Send email",
    "Security & setup warnings" : "Security & setup warnings",
    "All checks passed." : "All checks passed.",
    "There are some errors regarding your setup." : "There are some errors regarding your setup.",
    "There are some warnings regarding your setup." : "There are some warnings regarding your setup.",
    "Checking for system and security issues." : "Checking for system and security issues.",
    "Version" : "Version",
    "Server-side encryption" : "Server-side encryption",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed.",
    "Enable server-side encryption" : "Enable server-side encryption",
    "Please read carefully before activating server-side encryption: " : "Please read carefully before activating server-side encryption: ",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Encryption alone does not guarantee complete security. Please read the documentation for information on how the encryption app works, and supported use cases.",
    "Be aware that encryption always increases the file size." : "Be aware that encryption always increases the file size.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data.",
    "This is the final warning: Do you really want to enable encryption?" : "This is the final warning: Do you really want to enable encryption?",
    "Enable encryption" : "Enable encryption",
    "No encryption module loaded, please enable an encryption module in the app menu." : "No encryption module loaded, please enable an encryption module in the app menu.",
    "Select default encryption module:" : "Select default encryption module:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one.",
    "Start migration" : "Start migration",
    "Background jobs" : "Background jobs",
    "Last job ran %s." : "Last job ran %s.",
    "Last job execution ran %s. Something seems wrong." : "Last job execution ran %s. Something seems wrong.",
    "Background job didn’t run yet!" : "Background job didn’t run yet!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information.",
    "Execute one task with each page loaded" : "Execute one task with each page loaded",
    "The cron.php needs to be executed by the system user \"%s\"." : "The cron.php needs to be executed by the system user \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details.",
    "Sharing" : "Sharing",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "As admin you can fine-tune the sharing behavior. Please see the documentation for more information.",
    "Allow apps to use the Share API" : "Allow apps to use the Share API",
    "Allow users to share via link" : "Allow users to share via link",
    "Allow public uploads" : "Allow public uploads",
    "Always ask for a password" : "Always ask for a password",
    "Enforce password protection" : "Enforce password protection",
    "Set default expiration date" : "Set default expiry date",
    "Expire after " : "Expire after ",
    "days" : "days",
    "Enforce expiration date" : "Enforce expiry date",
    "Allow resharing" : "Allow resharing",
    "Allow sharing with groups" : "Allow sharing with groups",
    "Restrict users to only share with users in their groups" : "Restrict users to only share with users in their groups",
    "Exclude groups from sharing" : "Exclude groups from sharing",
    "These groups will still be able to receive shares, but not to initiate them." : "These groups will still be able to receive shares, but not to initiate them.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "This text will be shown on the public link upload page when the file list is hidden.",
    "Default share permissions" : "Default share permissions",
    "Personal" : "Personal",
    "Administration" : "Administration",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Like our Facebook page",
    "Follow us on Twitter" : "Follow us on Twitter",
    "Check out our blog" : "Check out our blog",
    "Subscribe to our newsletter" : "Subscribe to our newsletter",
    "Profile picture" : "Profile picture",
    "Upload new" : "Upload new",
    "Select from Files" : "Select from Files",
    "Remove image" : "Remove image",
    "png or jpg, max. 20 MB" : "png or jpg, max. 20 MB",
    "Picture provided by original account" : "Picture provided by original account",
    "Cancel" : "Cancel",
    "Choose as profile picture" : "Choose as profile picture",
    "Details" : "Details",
    "You are using <strong>%s</strong>" : "You are using <strong>%s</strong>",
    "Full name" : "Full name",
    "No display name set" : "No display name set",
    "Your email address" : "Your email address",
    "No email address set" : "No email address set",
    "For password reset and notifications" : "For password reset and notifications",
    "Phone number" : "Phone number",
    "Your phone number" : "Your phone number",
    "Address" : "Address",
    "Your postal address" : "Your postal address",
    "Website" : "Website",
    "It can take up to 24 hours before the account is displayed as verified." : "It can take up to 24 hours before the account is displayed as verified.",
    "Link https://…" : "Link https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter handle @…",
    "Help translate" : "Help translate",
    "Current password" : "Current password",
    "Change password" : "Change password",
    "Store credentials" : "Store credentials",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP.",
    "Use system cron service to call the cron.php file every 15 minutes." : "Use system cron service to call the cron.php file every 15 minutes."
},
"nplurals=2; plural=(n != 1);");
